/* aboutdialog.cpp  -- About class implementation for NoComprendo */
/*
   Copyright (C) 2019-2020 Bruno ANSELME <be.root@free.fr>

   This file is part of the NoComprendo software.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License v3 for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

/**
 * @file      aboutdialog.cpp
 * @author    Bruno ANSELME
 * @brief     AboutDialog class definition
 * @details   Display informations and help.
 */

#include <QDir>
#include <QSettings>
#include "aboutdialog.h"
#include "app_version.h"

//---------------------------
AboutDialog::AboutDialog(QString &lang, QWidget *parent) : QDialog(parent)
{
    ui.setupUi(this);
    setWindowTitle(tr("About %1").arg(APP_NAME));
    connect(ui.btHelp,          SIGNAL(clicked()), this, SLOT(showHelp()));
    connect(ui.btUsage,         SIGNAL(clicked()), this, SLOT(showUsage()));
    connect(ui.btVocabulary,    SIGNAL(clicked()), this, SLOT(showVocabulary()));
    connect(ui.btCommands,      SIGNAL(clicked()), this, SLOT(showCommands()));
    connect(ui.btSettings,      SIGNAL(clicked()), this, SLOT(showSettings()));
    connect(ui.btCredits,       SIGNAL(clicked()), this, SLOT(showCredits()));
    connect(ui.btLicense,       SIGNAL(clicked()), this, SLOT(showLicense()));
    connect(ui.btAboutQt,       SIGNAL(clicked()), qApp, SLOT(aboutQt()));
    locale = lang.left(2);
    QDir dir(QString(":/help/%1").arg(locale));
    if (!dir.exists()) locale = "en";
    ui.lbTitle->setText(QString("%1 - %2").arg(APP_NAME).arg(APP_VERSION));
    emit ui.btHelp->click();
    QSettings settings(APP_ORG, APP_NAME);
    move(settings.value("helpPos", QPoint(150, 250)).toPoint());
    resize(settings.value("helpSize", QSize(818, 600)).toSize());
}

AboutDialog::~AboutDialog() {
    QSettings settings(APP_ORG, APP_NAME);
    settings.setValue("helpPos",            pos());
    settings.setValue("helpSize",           size());
}

void AboutDialog::showPage(QString page)
{
    QFile file(QString(":/help/%1/%2.html").arg(locale).arg(page));
    if (!file.open(QIODevice::ReadOnly | QIODevice::Text))
            return;
    ui.tbHtml->setText(QString::fromUtf8(file.readAll()));
    file.close();
}

void AboutDialog::showLicense()
{
    QFile file(QString(":license-gpl-3.0.html"));
    if (!file.open(QIODevice::ReadOnly | QIODevice::Text))
            return;
    ui.tbHtml->setText(QString::fromUtf8(file.readAll()));
    file.close();
}

