/* commandset.h  -- CommandSet class definition for NoComprendo */
/*
   Copyright (C) 2019-2020 Bruno ANSELME <be.root@free.fr>

   This file is part of the NoComprendo software.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License v3 for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
#ifndef COMMANDSET_H
#define COMMANDSET_H

#include <QTableWidget>
#include "command.h"

#define COL_UTTERANCE   0
#define COL_TYPE        1
#define COL_COMMAND     2
#define COL_SET         3

class CommandSet : public QObject {
    Q_OBJECT
public:
    enum        ShortcutFormat { QtShortcut, XdoShortcut };                         // Qt format or KeySym format
public:
    explicit    CommandSet(QString fname);                                          //!< Create command set from file name
    QString     getCommandsUtterance();                                             //!< Return commands utterances for language model
    QString     getCommandsCSV();                                                   //!< Return commands utterances and action for CSV
    QString     getName()                                   { return name; }        //!< Return commands set name
    const       QMap<QString, Command *> *getCommands()     { return &commands; }   //!< Return commands table
    void        fillTable(QTableWidget *table, CommandSet::ShortcutFormat format);  //!< Fill GUI table with commands names and actions
public slots:
    void        loadCommands();                                                     //!< Load from file. This file is created from GUI by EditSet::accept()
private:
    QString                     filename;                                           // Commands set file name
    QString                     name;                                               // Commands set name
    QMap<QString, Command *>    commands;                                           // QString is the utterance linked to a command pointer
};

#endif // COMMANDSET_H
