/* editcommand.h  -- EditCommand class definition for NoComprendo */
/*
   Copyright (C) 2019-2020 Bruno ANSELME <be.root@free.fr>

   This file is part of the NoComprendo software.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License v3 for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef EDITSHORTCUT_H
#define EDITSHORTCUT_H

#include <QDialog>
#include <QButtonGroup>
#include "commandset.h"
#include "ui_editcommand.h"

namespace Ui {
    class dialCommand;
}

class EditCommand : public QDialog {
    Q_OBJECT
public:
    explicit    EditCommand(QString utt, Command &cmd);         //!< Constructor
    ~EditCommand();
    QKeySequence        getSequence();                          //!< Return current key sequence
    QString             getText();                              //!< Return current text
    Command::comType    getType();                              //!< Return current command type
    Command::metaType   getMeta();                              //!< Return current meta command type
    Command::mouseType  getMouse();                             //!< Return current mouse command type
    QString             getExec();                              //!< Return current exec command text
public slots:
    void            toMeta();                                   //!< Switch GUI to meta type
    void            toKey();                                    //!< Switch GUI to key sequence type
    void            toMouse();                                  //!< Switch GUI to mouse type
    void            toText();                                   //!< Switch GUI to text input type
    void            toExec();                                   //!< Switch GUI to exec type
    void            checkSequence(const QString &s);            //!< Check for valid key sequence
    void            checkExec(const QString &s);                //!< Check for valid execution command
    void            newKeySequence();                           //!< Read new key sequence from GUI
private:
    void            init();
    void            clearSignals(Command::comType newtype);
private:
    Ui::dialCommand    *ui;
    QButtonGroup        buts;
    Command::comType    lastType;
};

#endif // EDITSHORTCUT_H
