/* editset.h  -- EditSet class definition for NoComprendo */
/*
   Copyright (C) 2019-2020 Bruno ANSELME <be.root@free.fr>

   This file is part of the NoComprendo software.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License v3 for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef EDITCOMMAND_H
#define EDITCOMMAND_H

#include <QTextStream>
#include <QDir>
#include <QDialog>
#include <QKeySequenceEdit>
#include <QComboBox>
#include "commandset.h"
#include "ui_editset.h"
#include "params.h"

namespace Ui {
    class dialCommandSet;
}

class EditSet : public QDialog {
    Q_OBJECT
public:
    EditSet(t_params &p, QString setname);                    //!< Constructor for a given set name
    ~EditSet();
    void        loadVocabularyList(QString name);               //!< Load vocabulary list (left in UI)
    void        loadCommandTable();                             //!< Load commands table (right in UI)
signals:
    void        setUpdated();                                   //!< Send when set updated to update LM
public slots:
    void        accept();                                       //!< Accept dialog and save command set to file
    void        disableTooltips(bool);                          //!< Disable/enable GUI tooltips
    void        updateUtterance();                              //!< Update lbUtterance field in UI
private slots:
    void        addCommand();
    void        removeCommand();
    void        changeUtterance();
    void        editionCommand(int row, int column);
    void        editionCommand();
    void        tableActivated(int, int);
private:
    void        addField(int col, QString s, bool ok = true);
private:
    Ui::dialCommandSet *ui;
    t_params            params;
    bool                recording;
    QString             lastSequence;
    int                 comCount;
    QString             cmdfile;
    QStringList         vocabulary;
    bool                newcom;
};

#endif // EDITCOMMAND_H
