/* editvocabulary.h  -- EditVocabulary class definition for NoComprendo */
/*
   Copyright (C) 2019-2020 Bruno ANSELME <be.root@free.fr>

   This file is part of the NoComprendo software.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License v3 for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef EDITVOCABULARY_H
#define EDITVOCABULARY_H

#include <QDialog>
#include <QDir>
#include <comprendo.h>
#include "ui_editvocabulary.h"

namespace Ui {
    class dialVocabulary;
}

class EditVocabulary : public QDialog {
    Q_OBJECT
public:
    EditVocabulary(t_params &p, Comprendo *comp);   //!< Constructor. Load dictionary and vocabulary from files.
    ~EditVocabulary();
    void        accept();                           //!< Sort and accept dialog
    static void sortVocabulary(QString &txt);       //!< Sort vocabulary, static version with string parameter. Used by SelectSet::importSet
private slots:
    void        addWord();                          //!< Add word, top of vocabulary editor
    void        filterLanguage();                   //!< Dictionary filter
    void        sortVocabulary();                   //!< Sort vocabulary, string comes from gui editor
    void        showStats();                        //!< Compute and display words statistics
protected:
    void        paintEvent(QPaintEvent *);          //!< Restore mouse cursor when vocabulary is loaded
private:
    Ui::dialVocabulary *ui;
    t_params            params;
    QStringList         lines;
    bool                loading;
    Comprendo          *what;
};

#endif // EDITVOCABULARY_H
