/* guicontrol.h  -- Xdo access functions definition for NoComprendo */
/*
   Copyright (C) 2019-2020 Bruno ANSELME <be.root@free.fr>

   This file is part of the NoComprendo software.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License v3 for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef GUICONTROL_H
#define GUICONTROL_H

#include <QHash>

void        guiInit();                                      //!< Initialize libxdo and internal Qt to KeySym translation table
void        guiClose();                                     //!< Close libxdo
const char *guiVersion();                                   //!< Return gui version string
int         guiScreenSize(unsigned int *width, unsigned int *height, int screen);  //!< Return screen width and height
void        guiSendSequence(const char *seq);               //!< Send keys sequence
void        guiSendClick(int button);                       //!< Send mouse click (Left 1, middle 2, right 3, wheel up 4, wheel down 5)
void        guiSendDown(int button);                        //!< Send mouse pressed (Left 1, middle 2, right 3, wheel up 4, wheel down 5)
void        guiSendUp(int button);                          //!< Send mouse release (Left 1, middle 2, right 3, wheel up 4, wheel down 5)
void        guiMouseMove(int x, int y);                     //!< Relative mouse move
void        guiMouseTo(int x, int y);                       //!< Absolute mouse move
void        guiGetMousePos(int *x, int *y, int *screen);    //!< Return mouse position
void        guiSendText(const char *string);                //!< Text input
QString     guiKeySequence(QString cmd);                    //!< Convert Qt key sequence into KeySyms for guiSendSequence

#endif // GUICONTROL_H
