/* langchooser.cpp  -- LangChooser class definition for NoComprendo */
/*
   Copyright (C) 2020 Bruno ANSELME <be.root@free.fr>

   This file is part of the NoComprendo software.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License v3 for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

/**
 * @file      langchooser.cpp
 * @author    Bruno ANSELME
 * @brief     LangChooser class definition
 * @details   Select language from available acoustics models.
 */

#include <QDir>
#include "app_version.h"
#include "langchooser.h"

LangChooser::LangChooser() : QDialog()
{
    ui.setupUi(this);
    QDir pocketPath;                                            // params are not defined when called from main.cpp
    if (QApplication::applicationDirPath()=="/usr/bin") {       // Installation directories
        pocketPath       = QString(POCKET_PATH);
    } else {                                                    // Development directories
        pocketPath       = QApplication::applicationDirPath().append("/pocketsphinx/");
    }
    QStringList filter = { "??_??" };
    QStringList files = pocketPath.entryList(filter);           // Load available languages names
    for (int i = 0; i < files.count(); i++) {
        QLocale loc(files[i]);
        ui.cbLang->addItem(QString("%1/%2").arg(loc.nativeLanguageName()).arg(loc.nativeCountryName()), files[i]);
    }
    ui.lbTitle->setText(tr("Choose language"));
    ui.lbMessage->setText(tr("You system language is <b>%1/%2</b> : %3")
        .arg(QLocale::system().nativeLanguageName())
        .arg(QLocale::system().nativeCountryName())
        .arg(QLocale::system().name()));
    for (int i=0; i < files.count(); i++) {                     // auto select default language if present
        if (files[i] == QLocale::system().name())
            ui.cbLang->setCurrentIndex(i);
    }
}

QString LangChooser::getLang() {
    return ui.cbLang->currentData().toString();
}
