/* listener.cpp  -- Listener class implementation for NoComprendo */
/*
   Copyright (C) 2019-2020 Bruno ANSELME <be.root@free.fr>

   This file is part of the NoComprendo software.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License v3 for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

/**
 * @file      listener.cpp
 * @author    Bruno ANSELME
 * @brief     Listener class definition
 * @details   Run Comprendo::recognize_from_microphone in a different thread.
 */

#include "listener.h"

Listener::Listener(Comprendo *w) : QThread() {
    what    = w;
}

void Listener::run() {
    QString *word = what->recognize_from_microphone();      // blocking operation, done in a thread
    if (!word->isEmpty()) {
        QString result(*word);
        emit resultReady(result);
    }
    delete word;                                            // QString allocated in recognize_from_microphone
}
