/* mouseblink.cpp  -- Mouse animation class implementation for NoComprendo */
/*
   Copyright (C) 2020 Bruno ANSELME <be.root@free.fr>

   This file is part of the NoComprendo software.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License v3 for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

/**
 * @file      mouseblink.cpp
 * @author    Bruno ANSELME
 * @brief     MouseBlink class definition
 * @details   Mouse animation class for visual cursor location.
 */

#include <QPalette>
#include <QPainter>
#include "mouseblink.h"
#include "misc.h"

MouseBlink::MouseBlink(t_params *p) :
    QWidget(nullptr, Qt::FramelessWindowHint
            | Qt::WindowStaysOnTopHint
            | Qt::X11BypassWindowManagerHint
            | Qt::WindowDoesNotAcceptFocus
            | Qt::SplashScreen)
{
    params  = p;
    counter = 0;
    timerBlink  = 0;
    QRectF rscreens = getDesktopRect();
    setGeometry(rscreens.toRect());
    setAttribute(Qt::WA_TranslucentBackground, true);
}

void MouseBlink::start() {
    counter = 255/5;
    show();
    timerBlink  = startTimer(10);
}

void MouseBlink::timerEvent(QTimerEvent *event){
    if (event->timerId() == timerBlink) {
        counter--;
        update();
        if (!counter) {
            killTimer(timerBlink);
            timerBlink  = 0;
            hide();
        }
    }
}

void MouseBlink::paintEvent(QPaintEvent *event) {
    QWidget::paintEvent(event);
    QPainter    painter(this);
    QPen pen;
    pen.setWidth(2);
    pen.setColor(QColor(5*counter, 5*counter, 5*counter));
    painter.setPen(pen);
    painter.drawEllipse(QCursor::pos(), 10*counter, 10*counter);
    painter.drawEllipse(QCursor::pos(),  7*counter,  2*counter);
    painter.drawEllipse(QCursor::pos(),  2*counter,  7*counter);
}
