/* osd.h  -- OSD class definition for NoComprendo */
/*
   Copyright (C) 2019-2020 Bruno ANSELME <be.root@free.fr>

   This file is part of the NoComprendo software.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License v3 for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
#ifndef OSD_H
#define OSD_H

#include <QFrame>
#include <QLabel>
#include <QTimer>
#include "params.h"
#include "ui_osd.h"

namespace Ui {
    class OSD;
}

class OSDWindow : public QFrame
{
    Q_OBJECT
public:
    explicit    OSDWindow(t_params *p);                     //!< Constructor
    void        setText(QString s);                         //!< Set OSD text
    void        setFlashingText(QString s);                 //!< Set OSD text with limited time life
    void        setUnknown(QString s);                      //!< Set OSD colored text (unknown utterance)
    void        changeOsd(QPoint pos, QSize siz);           //!< Change OSD window position
    QPoint      getPosition()       { return pos();     }   //!< Get OSD window position (used by OSDEditor)
    QSize       getSize()           { return size();    }   //!< Get OSD window size (used by OSDEditor)
protected:
    void        paintEvent(QPaintEvent *event);             //!< Draw OSD window
protected slots:
    void        endTimer();                                 //!< Hide OSD window
    void        mouseMoveEvent(QMouseEvent *event);         //!< Drag OSD window (used by OSDEditor)
    void        mousePressEvent(QMouseEvent *event);        //!< Start dragging OSD window  (used by OSDEditor)
private:
    Ui::OSD    *ui;
    t_params   *params;
    QLabel      message;
    QTimer      timer;
    QPoint      offset;         // Offset while moving
    QRect       handle;         // Handle for resizing
    bool        resizing;       // Moving if not resizing
    QRect       rscreens;
    int         fontSize;
};

#endif // OSD_H
