/* osdeditor.cpp  -- OSD position editor class implementation for NoComprendo */
/*
   Copyright (C) 2019-2020 Bruno ANSELME <be.root@free.fr>

   This file is part of the NoComprendo software.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License v3 for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

/**
 * @file      osdeditor.cpp
 * @author    Bruno ANSELME
 * @brief     OSDEditor class definition
 * @details   OSD window editor.
 */

#include <QGuiApplication>
#include <QGraphicsTextItem>
#include <QScreen>
#include <QPainter>
#include "osdeditor.h"
#include "misc.h"

OSDEditor::OSDEditor(t_params *p) : QDialog(),
    osd(p)
{
    setWindowFlags(Qt::FramelessWindowHint | Qt::X11BypassWindowManagerHint);
    QRectF rscreens = getDesktopRect();
    setWindowOpacity(0.9);
    setGeometry(rscreens.toRect());
    QLabel  *lbl = new QLabel(tr("Resize and move OSD window.\nEscape or double-click background to quit."));
    lbl->setParent(this);
    lbl->move(100,100);
    QFont font(lbl->font());
    font.setPointSize(16);
    this->setFont(font);
    osd.setFixedHeight(p->osdSize.height());
    osd.setFixedWidth(p->osdSize.width());
    osd.setText(tr("On Screen Display"));
    osd.setFrameShape(QFrame::Box);
    osd.setWindowFlags(Qt::Widget);
    osd.setParent(this);
}

void OSDEditor::mouseDoubleClickEvent(QMouseEvent *) {
    emit accepted();
    close();
}
