/* params.h  -- Parameters structure definition for NoComprendo */
/*
   Copyright (C) 2019-2020 Bruno ANSELME <be.root@free.fr>

   This file is part of the NoComprendo software.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License v3 for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

/**
 * @file      params.h
 * @author    Bruno ANSELME
 * @details   Globals defines for NoComprendo.\n
 *              Don't edit last 5 defines, it's updated by "make version".
 */

#ifndef PARAMS_H
#define PARAMS_H

#include <QDir>
#include <QFile>

typedef struct {
    bool        development;            //!< Global flag, development version or installed program
    QString     lang;                   //!< Language (en_US, fr_FR...)
    QString     langShort;              //!< Language, two letters (en, fr, es...)
    // Globals paths
    QDir        appPath;                //!< Application path
    QDir        pocketPath;             //!< Pocketsphinx data path
    QDir        langPath;               //!< User dictionary and commands sets path
    // Files names (full paths)
    QString     lockFile;               //!< Lockfile
    QString     wordFile;               //!< Words liste file
    QString     corpusFile;             //!< Corpus file name
    QString     dictFile;               //!< Dictionary with phonetics
    QString     lmFile;                 //!< Language model file name
    QString     mouseFile;              //!< Utterances for Mouse MoveTo
    // General settings
    bool        autoStart;              //!< Auto start speech recognition
    bool        removeBadUtterance;     //!< Remove bad utterance flag
    bool        hideInTaskBar;          //!< Hide application icon in task bar
    bool        useSysTray;             //!< Use a system tray icon
    int         rFontSize;              //!< Reminder font size
    bool        rInvertColor;           //!< Inverted colors for reminder
    bool        ask2Quit;               //!< Confirm before exit
    int         maxlines;               //!< Max line count in console
    // LM settings
    bool        wordsToLM;              //!< Add vocabulary words to Language model
    // OSD settings
    bool        osdOn;                  //!< OSD on/off flag
    bool        osdAll;                 //!< Display all in OSD
    int         osdDuration;            //!< OSD duration (milliseconds)
    QPoint      osdPosition;            //!< OSD position
    QSize       osdSize;                //!< OSD size
    // Voice settings
    bool        speak;                  //!< eSpeak on/off flag
    int         voiceVariant;           //!< eSpeak voice ID
    int         gender;                 //!< eSpeak gender
    int         age;                    //!< eSpeak age
    // Mouse settings
    int         mouseStep;              //!< Mouse step for MoveLeft, MoveRight, MoveUp, MoveDown commands
    int         glideStep;              //!< Mouse glide step
    int         glideRate;              //!< Mouse glide rate (milliseconds)
    // Command line options
    bool        wordTrace;              //!< Print utterances to stdout
    bool        pocketTrace;            //!< Print pocketSphinx trace to stderr
} t_params;

#endif // PARAMS_H
