/* reminder.cpp  -- Reminder class implementation for NoComprendo */
/*
   Copyright (C) 2019-2020 Bruno ANSELME <be.root@free.fr>

   This file is part of the NoComprendo software.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License v3 for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

/**
 * @file      reminder.cpp
 * @author    Bruno ANSELME
 * @brief     Reminder class definition
 * @details   Full screen window for commands reminder.
 */

#include <QCoreApplication>
#include <QGridLayout>
#include "reminder.h"

Reminder::Reminder(t_params *p, Comprendo *comp) : QDialog()
{
    params  = p;
    what    = comp;
    setWindowFlags(Qt::WindowStaysOnTopHint | Qt::FramelessWindowHint );
    QGridLayout *layout = new QGridLayout(this);
    QListWidget *list = new QListWidget;
    layout->addWidget(list);
    QFont f = list->font();
    f.setPixelSize(params->rFontSize);
    list->setFont(f);
    list->setWrapping(true);
    list->setResizeMode(QListView::Adjust);
    list->addItems(comp->getCommandsList().split("\n"));
    list->setEnabled(false);
    QPalette palette = list->palette();
    palette.setColor(QPalette::Disabled, QPalette::Text, Qt::black);            // highlight disabled palette
    if (params->rInvertColor) {
        palette.setColor(QPalette::Disabled, QPalette::Text, Qt::white);        // invert colors
        palette.setColor(QPalette::Disabled, QPalette::Base, Qt::black);
    }
    list->setPalette(palette);
    Command    *com;
    QList<QListWidgetItem *> titles = list->findItems(QString("*"), Qt::MatchWildcard);
    for (int i = 0; i < titles.count(); i++) {
        if (titles[i]->text().contains(QRegExp("^-- "))) {                      // Commands set name
            titles[i]->setBackground(Qt::gray);
            titles[i]->setText(titles[i]->text().replace("-- ",""));
        } else {
            com = what->getCommand(titles[i]->text());
            if (com)
                titles[i]->setToolTip(com->getQtKey());
        }
    }
    showFullScreen();
}

void Reminder::changeEvent(QEvent *event) {         // Close dialog if focus is lost
    if (event->type() == QEvent::ActivationChange)
        if (!this->isActiveWindow())
            emit reject();
}

void Reminder::mousePressEvent(QMouseEvent *) {     // Close dialog on any mouse event
    emit reject();
}

void Reminder::keyPressEvent(QKeyEvent *) {         // Close dialog on any key event
    emit reject();
}
