/* selectset.h  -- SelectSet class definition for NoComprendo */
/*
   Copyright (C) 2019-2020 Bruno ANSELME <be.root@free.fr>

   This file is part of the NoComprendo software.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License v3 for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef SELECTSET_H
#define SELECTSET_H

#include <QDialog>
#include <QDir>
#include <comprendo.h>
#include "params.h"
#include "ui_setselector.h"

namespace Ui {
    class dialSelector;
}

class SelectSet : public QDialog {
    Q_OBJECT
public:
    SelectSet(t_params &p, Comprendo *w);               //!< Constructor, display commands sets list with checkboxes
    ~SelectSet();
    static  QStringList     getSetFiles(QString lang);  //!< Get list of selected commands sets
signals:
    void        setsUpdated();                          //!< One set has been updated. Connected to MainWindow::updateLanguageModel
public slots:
    void        accept();                               //!< Write settings before closing
    void        transmitSetUpdated();                   //!< Transmit signal from EditSet::setUpdated. Send SelectSet::setsUpdated
    void        viewLMFile();                           //!< Open FileViewer to show language model file
private slots:
    void            newSet();
    void            editSet();
    void            cloneSet();
    void            deleteSet();
    void            importSet();
    void            exportSet();
    void            exportCsv();
    void            writeSettings();
private:
    void            updateSets();
private:
    Ui::dialSelector   *ui;
    t_params            params;
    Comprendo          *what;
};

#endif // SELECTSET_H
