/* settings.h  -- Settings class definition for NoComprendo */
/*
   Copyright (C) 2019-2020 Bruno ANSELME <be.root@free.fr>

   This file is part of the NoComprendo software.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License v3 for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef SETTINGS_H
#define SETTINGS_H

#include <QDialog>
#include <QListWidget>
#include "params.h"
#include "osdeditor.h"
#include "ui_settings.h"

namespace Ui {
class NCSettings;
}

class Settings : public QDialog {
    Q_OBJECT
public:
    explicit    Settings(t_params *p);                  //!< Constructor. Initialize dialog's fields with t_params
    ~Settings();
public slots:
    void        accept();                               //!< Copy and save dialog's fields into t_params
    void        playVoice();                            //!< Try voice synthetizer
    void        moveOsd();                              //!< Change OSD position. Use OSDEditor.
    void        changeLanguage();                       //!< Change application language. Use LangChooser.
signals:
    void        sendInformation(const QString &);       //!< Send text to be shown in an information window by MainWindow
protected slots:
    void        editUtterance(int row, int column);     //!< Edit utterances for mouse MoveTo. Use UtteranceBuilder
    void        changeTaskBar(bool);                    //!< Tray check when not shown in taskbar
private:
    Ui::NCSettings     *ui;
    t_params           *params;
    QPoint              osdPosition;
    QSize               osdSize;
};

#endif // SETTINGS_H
