/* speak.cpp  -- Espeak access functions implementation for NoComprendo */
/*
   Copyright (C) 2019-2020 Bruno ANSELME <be.root@free.fr>

   This file is part of the NoComprendo software.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License v3 for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

/**
 * @file      speak.cpp
 * @author    Bruno ANSELME
 * @brief     eSpeak interface functions
 * @details   Interface to speech synthetizer
 */

#ifdef ENABLE_ESPEAK
#include <string.h>
#include <sstream>
#include <espeak/speak_lib.h>

static  char   *listVoicesString = nullptr;

void initSpeak() {
    espeak_AUDIO_OUTPUT output;
    char *path=nullptr;
    int Buflength = 500, Options=0;
    output = AUDIO_OUTPUT_PLAYBACK;
    espeak_Initialize(output, Buflength, path, Options );
    listVoicesString = nullptr;
}

char *listVoices(const char *lang) {
    if (listVoicesString != nullptr) return listVoicesString;      // List allready in memory
    espeak_VOICE *voice_select = espeak_GetCurrentVoice();
    strcpy((char *) voice_select->languages, lang);
    std::stringstream ss;
    const espeak_VOICE **list=espeak_ListVoices(voice_select);
    espeak_VOICE *voice = nullptr;
    for(; *list!=0 ; list++){
        voice = (espeak_VOICE *)(*list);
        if (voice)
            ss <<  voice->languages+1 << " : "  <<  voice->identifier << "\n";
    }
    std::string myString = ss.str();
    listVoicesString = new char[myString.length()+1];
    strcpy(listVoicesString, myString.c_str());
    return listVoicesString;
}

void setVoice(const char *lang, int gender, int age, int variant) {
    espeak_VOICE voice;
    memset(&voice, 0, sizeof(espeak_VOICE));                        // Zero out the voice first
    voice.name      = lang;
    voice.languages = nullptr;
    if (gender == 0) gender = 1;                                    // Force to male
    voice.gender    = static_cast<unsigned char>(gender);           // 0=not specified, 1=male, 2=female
    voice.age       = static_cast<unsigned char>(age);
    voice.variant   = variant;
    espeak_SetVoiceByProperties(&voice);
}

void sayIt(const char *text) {
    espeak_POSITION_TYPE position_type = POS_WORD;
    size_t Size;
    unsigned int position=0, end_position=0, flags=espeakCHARS_AUTO, *unique_identifier = nullptr;
    void* user_data = nullptr;
    Size = strlen(text)+1;
    espeak_Synth( text, Size, position, position_type, end_position, flags, unique_identifier, user_data );
    espeak_Synchronize();
}

const  char    *eSpeakVersion() {
    return espeak_Info(nullptr);
}
#endif
