/* trayicon.h  -- TrayIcon class definition for NoComprendo */
/*
   Copyright (C) 2020 Bruno ANSELME <be.root@free.fr>

   This file is part of the NoComprendo software.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License v3 for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
#ifndef TRAYICON_H
#define TRAYICON_H

#include <QMenu>
#include <QSystemTrayIcon>
#include "params.h"

class TrayIcon : public QSystemTrayIcon {
    Q_OBJECT
public:
    enum    Status     { Stopped,  Ready, Listening,  Suspended, ListenSuspend };
public:
    TrayIcon(t_params *p);                                      //!< Constructor. Prepare icons, messages, actions
    void            setStatus(Status s);                        //!< Set icon and tooltip
    void            setMenus(bool running, bool suspended);     //!< Enable/disable tray icon menus
public slots:
    void            sendStart();                                //!< Send trayStart signal
    void            sendStop();                                 //!< Send trayStop signal
    void            sendSuspend();                              //!< Send traySuspend signal
    void            sendQuit();                                 //!< Send trayQuit signal
    void            sendShow();                                 //!< Send trayShow signal
signals:
    void            trayStart();                                //!< Start signal sent to MainWindow
    void            trayStop();                                 //!< Stop signal sent to MainWindow
    void            traySuspend();                              //!< Suspend signal sent to MainWindow
    void            trayQuit();                                 //!< Quit signal sent to MainWindow
    void            trayShow();                                 //!< Show signal sent to MainWindow
private:
    t_params               *params;
    QMenu                   myMenu;
    QMap<Status, QIcon>     icons;
    QMap<Status, QString>   messages;
    QMap<Status, QAction *> actions;
};

#endif // TRAYICON_H
