/* utterancebuilder.cpp  -- Utterance builder for NoComprendo */
/*
   Copyright (C) 2019-2020 Bruno ANSELME <be.root@free.fr>

   This file is part of the NoComprendo software.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License v3 for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

/**
 * @file      utterancebuilder.cpp
 * @author    Bruno ANSELME
 * @brief     UtteranceBuilder class definition
 * @details   Utterance builder for mouse MoveTo utterances
 */

#include "utterancebuilder.h"
#include "misc.h"

UtteranceBuilder::UtteranceBuilder(t_params *params, QString oldutt) : QDialog(),
    ui(new Ui::UttBuilder)
{
    ui->setupUi(this);
    hide();
    ui->lbOldUtterance->setText(oldutt);
    QString txt = readFile(params->wordFile);
    QStringList         vocabulary;
    vocabulary = txt.split("\n");
    for (int i = 0; i < vocabulary.count(); i++) {
        if (!vocabulary[i].contains("("))
            ui->lstVoc->addItem(vocabulary[i]);
    }
    connect(ui->lstVoc,        SIGNAL(itemSelectionChanged()),     this,   SLOT(updateUtterance()));
}

void UtteranceBuilder::updateUtterance() {   // Update lbUtterance field in UI
    QList<QListWidgetItem *> selection = ui->lstVoc->selectedItems();
    QString cmd;
    for (int i = 0; i < selection.count(); i++) {
        cmd.append(selection[i]->text()).append(" ");
    }
    ui->lbUtterance->setText(cmd);
}

QString UtteranceBuilder::utterance() {
    return ui->lbUtterance->text();
}
