/* zoombutton.h  -- ZoomButton class definition for NoComprendo */
/*
   Copyright (C) 2019-2020 Bruno ANSELME <be.root@free.fr>

   This file is part of the NoComprendo software.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License v3 for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef ZOOMBUTTON_H
#define ZOOMBUTTON_H

#include <QList>
#include <QAbstractButton>
#include <comprendo.h>

// Special button class for Mouse MoveTo command. Based on keypads numbers.
class ZoomButton : public QAbstractButton
{
    Q_OBJECT
public:
    ZoomButton(t_params *p, Comprendo *comp = nullptr);                 //!< Constructor
    void            exec();                                             //!< Run event lopp
    bool            hasClicked()            { return done;      }       //!< True if zoom selection completed
    QPoint          where()                 { return here;      }       //!< Final mouse position
    virtual bool    eventFilter(QObject *obj, QEvent *event) override;  //!< Watch for focus lost
signals:
    void            zoomClicked();                                      //!< Sent to stop execution loop
    void            focusLost(bool in);                                 //!< Sent if window is desactivated
protected:
    void            timerEvent(QTimerEvent *event) override;            //!< Trigerred when an utterance is received
    void            paintEvent(QPaintEvent *) override;                 //!< Draw 9 boxes and call subboxes.
    void            keyReleaseEvent(QKeyEvent *e) override;             //!< Keys 1 to 9 can be used instead of voice command
    void            resizeEvent(QResizeEvent *e) override;              //!< Resized once when created
    void            drawGrid(QRect r, QPainter *painter, int level);    //!< Draw 9 boxes
    const QRect     rectNumber(QRect r, int num);                       //!< Get rectangle of last selected boxe
    void            pushFrame(int num);                                 //!< Stack frames (boxes)
    void            popFrame();                                         //!< Unstack frames
private:
    t_params           *params;
    Comprendo          *what;
    QList<QRect>        frames;
    QHash<QString, int> boxes;
    bool                done;
    QPoint              here;
    int                 timerid;
    QList<QRect>        screens;
    QPoint              offset;
};

#endif // ZOOMBUTTON_H
